#!b/in/sh
# $Id: 1_buildtools.sh 2 2016-07-24 17:50:19Z dettus $

echo " 
       -----         -----         
      /     \\       /     \\       /
     /       \\     /       \\     /
-----         -----         -----
     \\       /     \\       /     \\
      \\     /       \\     /       \\
       -----         ----- detLFS  -
      /     \\       /     \\       /
     /       \\     /       \\     /
-----         -----         -----
http://www.dettus.net/detLFS/detLFS_0.02.tar.gz

 The purpose of this script is to build the cross compiler to be used later.
 Hopefully, the previous scripts are finished at this point.
" ; date 





export TOOLSDIR=`pwd`/Tools
export BUILDDIR=`pwd`/Build
export SOURCESDIR=`pwd`/Sources
export DOWNLOADSDIR=`pwd`/Downloads

mkdir -p $BUILDDIR
mkdir -p $TOOLSDIR

export PATH=$TOOLSDIR/bin:$PATH



echo ">>> installing Kernel Headers" ; date 
(
	cd $BUILDDIR 
	cp -r $SOURCESDIR/linux .
	mkdir linux ; cd linux
	echo ">>>" ; date 
	cd linux
	mkdir -p $TOOLSDIR/usr/include/asm
	make -j 8 ARCH=arm INSTALL_HDR_PATH=$TOOLSDIR/usr headers_install  
)

echo ">>> installing glibc headers" ; date 
(
	cd $BUILDDIR
	mkdir glibc1 ; cd glibc1
	CC=gcc NM=nm $SOURCESDIR/glibc/configure --host=arm-linux-gnueabihf --prefix=$TOOLSDIR/ --with-headers=$TOOLSDIR/usr/include
	make -j 8 -k cross-compiling=yes install-headers  
	mkdir -p $TOOLSDIR/include/gnu/
	touch $TOOLSDIR/include/gnu/stubs.h
)
echo ">>> installing glibc headers" ; date 
(
	cd $BUILDDIR
	mkdir glibc2 ; cd glibc2
	CC=gcc NM=nm $SOURCESDIR/glibc/configure --host=arm-linux-gnueabihf --prefix=$TOOLSDIR/arm-linux-gnueabihf/ --with-headers=$TOOLSDIR/usr/include
	make -j 8 -k cross-compiling=yes install-headers  
	mkdir -p $TOOLSDIR/arm-linux-gnueabihf/include/gnu/
	touch $TOOLSDIR/arm-linux-gnueabihf/include/gnu/stubs.h
)
echo ">>> building binutils (cross)" ; date 
(
	cd $BUILDDIR
	mkdir binutils1 ; cd binutils1
	$SOURCESDIR/binutils/configure --target=arm-linux-gnueabihf --prefix=$TOOLSDIR --with-sysroot --disable-nls --disable-werror
	make  -j 8 && make install
)
echo ">>> building gcc (cross)" ; date 
(
	cd $BUILDDIR
	mkdir gcc1 ; cd gcc1
	$SOURCESDIR/gcc/configure --target=arm-linux-gnueabihf --prefix=$TOOLSDIR --disable-nls --disable-shared --enable-languages=c,c++ --disable-multilib --with-headers=$TOOLSDIR/usr/include --with-build-time-tools=$TOOLSDIR --with-build-sysroot=$TOOLSDIR
	make -j 8 all-gcc && make -j 8 all-target-libgcc && make install-gcc && make install-target-libgcc

)

echo "At this point, the cross compiler can be used to build the glibc" ; date 
export PATH=$TOOLSDIR/bin:$TOOLSDIR/usr/bin:$PATH
echo ">>> installing glibc (for real)" ; date 
(
	cd $BUILDDIR
	mkdir glibc3 ; cd glibc3
	$SOURCESDIR/glibc/configure --host=arm-linux-gnueabihf --prefix=$TOOLSDIR --with-headers=$TOOLSDIR/usr/include
	make -j 8 cross-compiling=yes
	make -j 8 cross-compiling=yes  install
	make install
)

echo ">>> installing glibc (for the build)" ; date 
(
	cd $BUILDDIR
	mkdir glibc4 ; cd glibc4
	$SOURCESDIR/glibc/configure --host=arm-linux-gnueabihf --prefix=$TOOLSDIR/arm-linux-gnueabihf/ --with-headers=$TOOLSDIR/usr/include
	echo ">>>" ; date 
	make -j 8 cross-compiling=yes
	make -j 8 cross-compiling=yes  install
	make install
)
echo ">>> building gcc (with shared)" ; date 
(
	cd $BUILDDIR
	mkdir gcc2 ; cd gcc2
	$SOURCESDIR/gcc/configure --target=arm-linux-gnueabihf --prefix=$TOOLSDIR --disable-nls --enable-languages=c,c++ --disable-multilib --with-headers=$TOOLSDIR/usr/include --with-build-time-tools=$TOOLSDIR
	echo ">>>" ; date 
	make -j 8 all-gcc && make -j 8 all-target-libgcc && make install-gcc && make install-target-libgcc
	make -j 8
	make install
)


echo "Checking the Tools" ; date 
$TOOLSDIR/bin/arm-linux-gnueabihf-gcc -o Helloworld_shared.app helloworld.c
$TOOLSDIR/bin/arm-linux-gnueabihf-gcc -static -o Helloworld_static.app helloworld.c
file Helloworld_shared.app
file Helloworld_static.app
echo ">>> done" ; date 
